package betterquesting.blocks;

import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.tasks.IFluidTask;
import betterquesting.api.questing.tasks.IItemTask;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.cache.QuestCache;
import betterquesting.api2.storage.DBEntry;
import betterquesting.core.BetterQuesting;
import betterquesting.questing.QuestDatabase;
import betterquesting.storage.QuestSettings;
import java.util.UUID;
import javax.annotation.Nonnull;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.inventory.ISidedInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.network.NetworkManager;
import net.minecraft.network.Packet;
import net.minecraft.network.play.server.S35PacketUpdateTileEntity;
import net.minecraft.server.MinecraftServer;
import net.minecraft.tileentity.TileEntity;
import net.minecraftforge.common.util.ForgeDirection;
import net.minecraftforge.fluids.Fluid;
import net.minecraftforge.fluids.FluidStack;
import net.minecraftforge.fluids.FluidTankInfo;
import net.minecraftforge.fluids.IFluidHandler;

/* loaded from: betterquesting_blocks.jar:betterquesting/blocks/TileSubmitStation.class */
public class TileSubmitStation extends TileEntity implements IFluidHandler, ISidedInventory {
    private ItemStack[] itemStack = new ItemStack[2];
    private boolean needsUpdate = false;
    public UUID owner = null;
    public int questID = -1;
    public int taskID = -1;
    private DBEntry<IQuest> qCached;
    private static final int[] slotsForFace = {0, 1};

    public DBEntry<IQuest> getQuest() {
        IQuest tmp;
        if (this.questID < 0) {
            return null;
        }
        if (this.qCached == null && (tmp = (IQuest) QuestDatabase.INSTANCE.getValue(this.questID)) != null) {
            this.qCached = new DBEntry<>(this.questID, tmp);
        }
        return this.qCached;
    }

    public ITask getRawTask() {
        DBEntry<IQuest> q = getQuest();
        if (q == null || this.taskID < 0) {
            return null;
        }
        return (ITask) ((IQuest) q.getValue()).getTasks().getValue(this.taskID);
    }

    public IItemTask getItemTask() {
        IItemTask rawTask = getRawTask();
        if (rawTask != null && (rawTask instanceof IItemTask)) {
            return rawTask;
        }
        return null;
    }

    public IFluidTask getFluidTask() {
        IFluidTask rawTask = getRawTask();
        if (rawTask != null && (rawTask instanceof IFluidTask)) {
            return rawTask;
        }
        return null;
    }

    public int func_70302_i_() {
        return 2;
    }

    public ItemStack func_70301_a(int idx) {
        if (idx < 0 || idx >= this.itemStack.length) {
            return null;
        }
        return this.itemStack[idx];
    }

    public ItemStack func_70298_a(int idx, int amount) {
        if (idx < 0 || idx >= this.itemStack.length || this.itemStack[idx] == null) {
            return null;
        }
        if (amount >= this.itemStack[idx].field_77994_a) {
            ItemStack itemstack = this.itemStack[idx];
            this.itemStack[idx] = null;
            return itemstack;
        }
        this.itemStack[idx].field_77994_a -= amount;
        ItemStack cpy = this.itemStack[idx].func_77946_l();
        cpy.field_77994_a = amount;
        return cpy;
    }

    public ItemStack func_70304_b(int slot) {
        return null;
    }

    public void func_70299_a(int idx, ItemStack stack) {
        if (idx < 0 || idx >= this.itemStack.length) {
            return;
        }
        this.itemStack[idx] = stack;
    }

    @Nonnull
    public String func_145825_b() {
        return BetterQuesting.submitStation.func_149732_F();
    }

    public boolean func_145818_k_() {
        return false;
    }

    public int func_70297_j_() {
        return 64;
    }

    public boolean func_70300_a(EntityPlayer player) {
        return (this.owner == null || player.func_110124_au().equals(this.owner)) && player.func_70092_e((double) this.field_145851_c, (double) this.field_145848_d, (double) this.field_145849_e) < 256.0d;
    }

    public void func_70295_k_() {
    }

    public void func_70305_f() {
    }

    public boolean func_94041_b(int idx, ItemStack stack) {
        IItemTask t;
        return idx == 0 && (t = getItemTask()) != null && this.itemStack[idx] == null && !t.isComplete(this.owner) && t.canAcceptItem(this.owner, getQuest(), stack);
    }

    public int fill(ForgeDirection from, FluidStack fluid, boolean doFill) {
        IFluidTask t = getFluidTask();
        if (!isSetup() || t == null) {
            return 0;
        }
        int amount = fluid.amount;
        int consumed = 0;
        if (doFill) {
            FluidStack remainder = t.submitFluid(this.owner, getQuest(), fluid);
            consumed = remainder != null ? amount - remainder.amount : amount;
            if (t.isComplete(this.owner)) {
                this.needsUpdate = true;
                reset();
                MinecraftServer server = MinecraftServer.func_71276_C();
                if (server != null) {
                    server.func_71203_ab().func_148543_a((EntityPlayer) null, this.field_145851_c, this.field_145848_d, this.field_145849_e, 128.0d, this.field_145850_b.field_73011_w.field_76574_g, func_145844_m());
                }
            } else {
                this.needsUpdate = consumed > 0;
            }
        }
        return consumed;
    }

    public FluidStack drain(ForgeDirection from, FluidStack resource, boolean doDrain) {
        return null;
    }

    public FluidStack drain(ForgeDirection from, int maxDrain, boolean doDrain) {
        return null;
    }

    public boolean canFill(ForgeDirection from, Fluid fluid) {
        IFluidTask t = getFluidTask();
        return (t == null || t.isComplete(this.owner) || !t.canAcceptFluid(this.owner, getQuest(), new FluidStack(fluid, 1))) ? false : true;
    }

    public boolean canDrain(ForgeDirection from, Fluid fluid) {
        return false;
    }

    public FluidTankInfo[] getTankInfo(ForgeDirection from) {
        return new FluidTankInfo[0];
    }

    public void func_145845_h() {
        if (this.field_145850_b.field_72995_K || !isSetup() || ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.EDIT_MODE)).booleanValue()) {
            return;
        }
        long wtt = this.field_145850_b.func_82737_E();
        if (wtt % 10 == 0 && this.owner != null) {
            if (wtt % 20 == 0) {
                this.qCached = null;
            }
            DBEntry<IQuest> q = getQuest();
            IItemTask t = getItemTask();
            MinecraftServer server = MinecraftServer.func_71276_C();
            EntityPlayerMP player = getPlayerByUUID(this.owner);
            QuestCache qc = player == null ? null : player.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
            if (q != null && t != null && this.itemStack[0] != null && this.itemStack[1] == null) {
                ItemStack inStack = this.itemStack[0].func_77946_l();
                ItemStack beforeStack = this.itemStack[0].func_77946_l();
                if (t.canAcceptItem(this.owner, getQuest(), inStack)) {
                    this.itemStack[0] = t.submitItem(this.owner, getQuest(), inStack);
                    if (t.isComplete(this.owner)) {
                        reset();
                        this.needsUpdate = true;
                        if (server != null) {
                            server.func_71203_ab().func_148543_a((EntityPlayer) null, this.field_145851_c, this.field_145848_d, this.field_145849_e, 128.0d, this.field_145850_b.field_73011_w.field_76574_g, func_145844_m());
                        }
                    } else if (this.itemStack[0] == null || !this.itemStack[0].equals(beforeStack)) {
                        this.needsUpdate = true;
                    }
                } else {
                    this.itemStack[1] = inStack;
                    this.itemStack[0] = null;
                }
            }
            if (this.needsUpdate) {
                this.needsUpdate = false;
                if (q != null && qc != null) {
                    qc.markQuestDirty(this.questID);
                }
            }
            if (t != null && t.isComplete(this.owner)) {
                reset();
                MinecraftServer.func_71276_C().func_71203_ab().func_148543_a((EntityPlayer) null, this.field_145851_c, this.field_145848_d, this.field_145849_e, 128.0d, this.field_145850_b.field_73011_w.field_76574_g, func_145844_m());
            }
        }
    }

    private EntityPlayerMP getPlayerByUUID(UUID uuid) {
        MinecraftServer server = MinecraftServer.func_71276_C();
        if (server == null) {
            return null;
        }
        for (EntityPlayerMP player : server.func_71203_ab().field_72404_b) {
            if (player.func_146103_bH().getId().equals(uuid)) {
                return player;
            }
        }
        return null;
    }

    public void setupTask(UUID owner, IQuest quest, ITask task) {
        if (owner == null || quest == null || task == null) {
            reset();
            return;
        }
        this.questID = QuestDatabase.INSTANCE.getID(quest);
        this.qCached = new DBEntry<>(this.questID, quest);
        this.taskID = quest.getTasks().getID(task);
        if (this.questID < 0 || this.taskID < 0) {
            reset();
        } else {
            this.owner = owner;
            func_70296_d();
        }
    }

    public boolean isSetup() {
        return this.owner != null && this.questID >= 0 && this.taskID >= 0;
    }

    public void reset() {
        this.owner = null;
        this.questID = -1;
        this.taskID = -1;
        this.qCached = null;
        func_70296_d();
    }

    @Nonnull
    public Packet func_145844_m() {
        NBTTagCompound nbtTagCompound = new NBTTagCompound();
        func_145841_b(nbtTagCompound);
        return new S35PacketUpdateTileEntity(this.field_145851_c, this.field_145848_d, this.field_145849_e, 0, nbtTagCompound);
    }

    public void onDataPacket(NetworkManager net, S35PacketUpdateTileEntity pkt) {
        func_145839_a(pkt.func_148857_g());
    }

    public void func_145839_a(NBTTagCompound tags) {
        super.func_145839_a(tags);
        this.itemStack[0] = ItemStack.func_77949_a(tags.func_74775_l("input"));
        this.itemStack[1] = ItemStack.func_77949_a(tags.func_74775_l("output"));
        try {
            this.owner = UUID.fromString(tags.func_74779_i("owner"));
            this.questID = tags.func_74764_b("questID") ? tags.func_74762_e("questID") : -1;
            this.taskID = tags.func_74764_b("task") ? tags.func_74762_e("task") : -1;
            if (!isSetup()) {
                reset();
            }
        } catch (Exception e) {
            reset();
        }
    }

    @Nonnull
    public void func_145841_b(NBTTagCompound tags) {
        super.func_145841_b(tags);
        tags.func_74778_a("owner", this.owner != null ? this.owner.toString() : "");
        tags.func_74768_a("questID", this.questID);
        tags.func_74768_a("task", this.taskID);
        tags.func_74782_a("input", this.itemStack[0] != null ? this.itemStack[0].func_77955_b(new NBTTagCompound()) : new NBTTagCompound());
        tags.func_74782_a("output", this.itemStack[1] != null ? this.itemStack[1].func_77955_b(new NBTTagCompound()) : new NBTTagCompound());
    }

    @Nonnull
    public int[] func_94128_d(int side) {
        return slotsForFace;
    }

    public boolean func_102007_a(int slot, ItemStack stack, int side) {
        return func_94041_b(slot, stack);
    }

    public boolean func_102008_b(int slot, ItemStack stack, int side) {
        return slot == 1;
    }
}
